// ----------------------------------------------------------------------------
// Primes2.java
// printing prime numbers
// 
// Author:  Wolfgang Schreiner <Wolfgang.Schreiner@fhs-hagenberg.ac.at>
// Created: August 25, 2001
// ----------------------------------------------------------------------------
public class Primes2
{
  // --------------------------------------------------------------------------
  // * reads from standard input stream a number 'n'
  // * prints all primes less than 'n'
  // -----------------------------------------------------------------------
  public static void main(String[] args)
  {
    int n = Input.readInt();
    printPrimes(n);
  }

  // -----------------------------------------------------------------------
  // prints all primes less than 'n' in ascending order, one prime per line
  // -----------------------------------------------------------------------
  public static void printPrimes(int n)
  {
    if (n < 2) return;
    System.out.println(2);         // 2 is prime
				   
    Table p = new Table();         // prime table
    for (int c = 3; c < n; c += 2) // check odd candidates c
    {				   
      if (!isPrime(c, p)) continue;         	   
      System.out.println(c);
      p.add(c);
    }
  }

  // -----------------------------------------------------------------------
  // isPrime(c, p, l)
  // 'c' is prime according to prime table 'p'
  //
  // Input condition:
  //   'p' is not null and holds the first 'l' odd primes
  //   'c' is odd and there is no prime between the maximum prime in 'p'
  //   and 'c'.
  //
  // Output condition:
  //   returns true if and only if 'c' is prime.
  // -----------------------------------------------------------------------
  public static boolean isPrime(int c, Table p)
  {
    final int l = p.getNumber();
    for (int i = 0; i < l; i++)
      if (c % p.getElement(i) == 0) return false;
    return true;
  }

  // -----------------------------------------------------------------------
  // q = resize(p, len)
  // q is the resized version of 'p' that has 'len' elements
  //
  // Input condition:
  //   'p' is not null and has length 'l' less than or equal to 'len'.
  // Output condition:
  //   'q' is of length 'len' and has in its first 'l' positions
  //   the same elements as 'p'.
  // -----------------------------------------------------------------------
  public static int[] resize(int[] p, int len)
  {
    int l = p.length;
    int[] q = new int[len];
    for (int i = 0; i < l; i++)
      q[i] = p[i];
    return q;
  }
}
